@@ -8,7 +8,7 @@ use swc_ecma_ast::*;
 use swc_ecma_parser::parse_file_as_expr;
 use swc_ecma_utils::drop_span;
 
-use super::{true_by_default, CompressOptions, TopLevelOptions};
+use super::{default_passes, true_by_default, CompressOptions, TopLevelOptions};
 use crate::option::PureGetterOption;
 
 #[derive(Debug, Clone, Serialize, Deserialize)]
@@ -166,7 +166,7 @@ pub struct TerserCompressorOptions {
     #[serde(default)]
     pub negate_iife: Option<bool>,
 
-    #[serde(default)]
+    #[serde(default = "default_passes")]
     pub passes: usize,
 
     #[serde(default)]
@@ -246,63 +246,7 @@ pub struct TerserCompressorOptions {
 
 impl Default for TerserCompressorOptions {
     fn default() -> Self {
-        Self {
-            arguments: Default::default(),
-            arrows: Default::default(),
-            booleans: Default::default(),
-            booleans_as_integers: Default::default(),
-            collapse_vars: Default::default(),
-            comparisons: Default::default(),
-            computed_props: Default::default(),
-            conditionals: Default::default(),
-            dead_code: Default::default(),
-            defaults: true,
-            directives: Default::default(),
-            drop_console: Default::default(),
-            drop_debugger: Default::default(),
-            ecma: Default::default(),
-            evaluate: Default::default(),
-            expression: Default::default(),
-            global_defs: Default::default(),
-            hoist_funs: Default::default(),
-            hoist_props: Default::default(),
-            hoist_vars: Default::default(),
-            ie8: Default::default(),
-            if_return: Default::default(),
-            inline: Default::default(),
-            join_vars: Default::default(),
-            keep_classnames: Default::default(),
-            keep_fargs: Default::default(),
-            keep_fnames: Default::default(),
-            keep_infinity: Default::default(),
-            loops: Default::default(),
-            negate_iife: Default::default(),
-            passes: Default::default(),
-            properties: Default::default(),
-            pure_getters: Default::default(),
-            pure_funcs: Default::default(),
-            reduce_funcs: Default::default(),
-            reduce_vars: Default::default(),
-            sequences: Default::default(),
-            side_effects: Default::default(),
-            switches: Default::default(),
-            top_retain: Default::default(),
-            toplevel: Default::default(),
-            typeofs: Default::default(),
-            unsafe_passes: Default::default(),
-            unsafe_arrows: Default::default(),
-            unsafe_comps: Default::default(),
-            unsafe_function: Default::default(),
-            unsafe_math: Default::default(),
-            unsafe_symbols: Default::default(),
-            unsafe_methods: Default::default(),
-            unsafe_proto: Default::default(),
-            unsafe_regexp: Default::default(),
-            unsafe_undefined: Default::default(),
-            unused: Default::default(),
-            module: Default::default(),
-            const_to_let: Default::default(),
-        }
+        serde_json::from_value(serde_json::Value::Object(Default::default())).unwrap()
     }
 }
 
